********************
Installation is Easy
********************
/** 

Recommendation to use Virtual Environment

**/


1 ) Download from::
	http://scm.sparrowsms.com/sparrow/sparrowsdk.git

2) cd SparrowSDK
	OR
	sparrowsdk

3) Installing in Virtual Environment
	$: mkvirtualenv sparrow
	(sparrow)$:python setup.py install
else 
	$:python setup.py install

Note :: You may require root access if installing in system

Sparrow  Python SDK

This client library is designed to support the Sparrow sms Api and the official SparrowSmsSDK, which is the canonical way to implement Sparrow sms Outgoing api. You can read more about the API by accessing its official documentation.

Send SMS:
*******************************
from sparrow import PushClient
pushclient = PushClient(client_id='client_id', username='username', password='password')
push_queue = pushclient.enqueue(destination='destination list, tuple or string seperated by commas', message='message')
push_resp = pushclient.send()

*******************************

Simulate Send SMS:
*******************************
from sparrow import PushClient
pushclient = PushClient(client_id='client_id', username='username', password='password')
push_queue = pushclient.enqueue(destination='destination list, tuple or string seperated by commas', message='message')
push_resp = pushclient.simulate()

*******************************

Check Credit Status:
*******************************
from sparrow import PushClient
pushclient = PushClient(client_id='client_id', username='username', password='password')
push_resp = pushclient.credit_status()

*******************************

Request for Credit Topup:
*******************************
from sparrow import PushClient
pushclient = PushClient(client_id='client_id', username='username', password='password')
push_resp = pushclient.topup(amount='credit_amount')

*******************************

Having trouble with Pages? we’ll help you sort it out. developers@sparrowsms.com
